/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.dispatch.talend.web.internal.metadata;

import com.liferay.dispatch.metadata.DispatchTriggerMetadata;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * @author Igor Beslic
 */
public class TalendDispatchTriggerMetadata implements DispatchTriggerMetadata {

	@Override
	public Map<String, String> getAttributes() {
		return _attributes;
	}

	@Override
	public Map<String, String> getErrors() {
		return _errors;
	}

	@Override
	public boolean isDispatchTaskExecutorReady() {
		return _ready;
	}

	public static class Builder {

		public Builder attribute(String key, String value) {
			_attributes.put(key, value);

			return this;
		}

		public TalendDispatchTriggerMetadata build() {
			return new TalendDispatchTriggerMetadata(this);
		}

		public Builder error(String key, String value) {
			_errors.put(key, value);

			return this;
		}

		public Builder ready(boolean ready) {
			_ready = ready;

			return this;
		}

		private final Map<String, String> _attributes = new HashMap<>();
		private final Map<String, String> _errors = new HashMap<>();
		private boolean _ready;

	}

	private TalendDispatchTriggerMetadata(Builder builder) {
		_attributes = Collections.unmodifiableMap(builder._attributes);
		_errors = Collections.unmodifiableMap(builder._errors);
		_ready = builder._ready;
	}

	private final Map<String, String> _attributes;
	private final Map<String, String> _errors;
	private final boolean _ready;

}