/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.dispatch.talend.web.internal.metadata;

import com.liferay.dispatch.metadata.DispatchTriggerMetadata;
import com.liferay.dispatch.metadata.DispatchTriggerMetadataFactory;
import com.liferay.dispatch.model.DispatchTrigger;
import com.liferay.dispatch.repository.DispatchFileRepository;
import com.liferay.dispatch.talend.web.internal.executor.TalendDispatchTaskExecutor;
import com.liferay.expando.kernel.exception.DuplicateColumnNameException;
import com.liferay.expando.kernel.exception.DuplicateTableNameException;
import com.liferay.expando.kernel.model.ExpandoColumnConstants;
import com.liferay.expando.kernel.model.ExpandoTable;
import com.liferay.expando.kernel.service.ExpandoColumnLocalService;
import com.liferay.expando.kernel.service.ExpandoTableLocalService;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.repository.model.FileEntry;
import com.liferay.portal.kernel.service.CompanyLocalService;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Igor Beslic
 */
@Component(
	immediate = true,
	property = "dispatch.task.executor.type=" + TalendDispatchTaskExecutor.TALEND,
	service = DispatchTriggerMetadataFactory.class
)
public class TalendDispatchTriggerMetadataFactory
	implements DispatchTriggerMetadataFactory {

	@Override
	public DispatchTriggerMetadata instance(DispatchTrigger dispatchTrigger) {
		FileEntry fileEntry = _dispatchFileRepository.fetchFileEntry(
			dispatchTrigger.getDispatchTriggerId());

		TalendDispatchTriggerMetadata.Builder builder =
			new TalendDispatchTriggerMetadata.Builder();

		if (fileEntry != null) {
			builder.ready(true);

			return builder.build();
		}

		builder.error("talend-archive-file-misses", null);
		builder.ready(false);

		return builder.build();
	}

	@Activate
	protected void activate() {
		_companyLocalService.forEachCompany(
			company -> {
				try {
					_setupExpando(company.getCompanyId());
				}
				catch (Exception exception) {
					_log.error("Unable to setup expando", exception);
				}
			});
	}

	private void _setupExpando(long companyId) throws Exception {
		ExpandoTable expandoTable = null;

		try {
			expandoTable = _expandoTableLocalService.addTable(
				companyId, DispatchTrigger.class.getName(),
				"DispatchArchiveFile");
		}
		catch (DuplicateTableNameException duplicateTableNameException) {
			if (_log.isDebugEnabled()) {
				_log.debug(
					duplicateTableNameException, duplicateTableNameException);
			}

			expandoTable = _expandoTableLocalService.getTable(
				companyId, DispatchTrigger.class.getName(),
				"DispatchArchiveFile");
		}

		try {
			_expandoColumnLocalService.addColumn(
				expandoTable.getTableId(), "dispatchTriggerId",
				ExpandoColumnConstants.STRING);
			_expandoColumnLocalService.addColumn(
				expandoTable.getTableId(), "fileName",
				ExpandoColumnConstants.STRING);
		}
		catch (DuplicateColumnNameException duplicateColumnNameException) {
			if (_log.isDebugEnabled()) {
				_log.debug(
					duplicateColumnNameException, duplicateColumnNameException);
			}
		}
	}

	private static final Log _log = LogFactoryUtil.getLog(
		TalendDispatchTriggerMetadataFactory.class);

	@Reference
	private CompanyLocalService _companyLocalService;

	@Reference
	private DispatchFileRepository _dispatchFileRepository;

	@Reference
	private ExpandoColumnLocalService _expandoColumnLocalService;

	@Reference
	private ExpandoTableLocalService _expandoTableLocalService;

}